==> jils-0.2.0.tgz: package/jils.js <==
var rl = require('readline'),
	fs = require('fs'),
    sys = require('sys');

var core = require('./lib/core'),
	macro = require('./lib/macro');

var global = {
	values: {
		'eq?': core.eqp,
		'equal?': core.equalp,
		'list?': core.arrayp,
		'hash?': core.hashp,
		'function?': core.functionp,
		'number?': core.numberp,
		'string?': core.stringp,
		'undefined?': core.undefinedp,
		'null?': core.nullp,
		'+': core.plus,
		'-': core.minus,
		'*': core.mult,
		'/': core.div,
		'=': core.eq,
		'>': core.gt,
		'>=': core.gte,
		'<': core.lt,
		'<=': core.lte,
		'get': core.get,
		'assoc': core.assoc,
		'keys': core.keys,
		'values': core.values,
		'nth': core.nth,
		'length': core.length,
		'cons': core.cons,
		'car': core.car,
		'cdr': core.cdr,
		'append': core.append,
		'mapf': core.map,
		'reducef': core.reduce,
		'defun': macro.defun,
		'map': macro.map,
		'load': macro.load
	}
}

exports.global = global;

var parse = require('./lib/parse').parse;
exports.parse = parse;

require.extensions['.jils'] = function(md, file){
	parse('(begin '
		+fs.readFileSync(file, 'utf-8').toString()
			+')', global);
};


var interactive = false;
if (process.argv.length > 1){
	var args = process.argv.slice(1);
		script = (__filename.split('/').pop());
	if (args[0].indexOf(script) > -1){
		args = args.slice(1);
	}
	if (args[0] === '-i'){
		interactive = true;
		args = args.slice(1);
	}
	if (!args.length) interactive = true;	

	args.forEach(function(file){
		parse('(begin '
			+fs.readFileSync(file).toString()
				+')', global);
	});
} else {
	interactive = false;
}

if (interactive) {
	var repl = rl.createInterface(
		process.stdin, 
		process.stdout, null);

	var prompt = 'jils> ',
		colors = {
			pre: "\033[1;31m", 
			post: "\033[m"
		};

	var issue = fs.readFileSync('./issue.txt');
	console.log(issue.toString());	
	
	repl.question(prompt, function next(input){
		if (!input) return repl.question(prompt, next);
		switch (input.split(' ')[0]){
			case ':q': process.exit(0);
		} 
		var result = parse(input, global),
			output = colors.pre + result + colors.post;
		console.log(output);
		repl.question(prompt, next);
	});
}

==> jils-0.3.0.tgz: package/jils.js <==
var rl = require('readline'),
	fs = require('fs'),
    sys = require('sys');

var core = require('./lib/core'),
	macro = require('./lib/macro');

var global = {
	values: {
		'eq?': core.eqp,
		'equal?': core.equalp,
		'list?': core.arrayp,
		'hash?': core.hashp,
		'function?': core.functionp,
		'number?': core.numberp,
		'string?': core.stringp,
		'undefined?': core.undefinedp,
		'null?': core.nullp,
		'+': core.plus,
		'-': core.minus,
		'*': core.mult,
		'/': core.div,
		'=': core.eq,
		'>': core.gt,
		'>=': core.gte,
		'<': core.lt,
		'<=': core.lte,
		'get': core.get,
		'assoc': core.assoc,
		'keys': core.keys,
		'values': core.values,
		'nth': core.nth,
		'length': core.length,
		'cons': core.cons,
		'car': core.car,
		'cdr': core.cdr,
		'append': core.append,
		'mapf': core.map,
		'reducef': core.reduce,
		'defun': macro.defun,
		'map': macro.map,
		'load': macro.load
	}
}

exports.global = global;

var parse = require('./lib/parse').parse;
exports.parse = parse;

require.extensions['.jils'] = function(md, file){
	parse('(begin '
		+fs.readFileSync(file, 'utf-8')
			+')', global);
};


var interactive = false;
if (process.argv.length > 1){
	var args = process.argv.slice(1);
		script = (__filename.split('/').pop());
	if (args[0].indexOf(script) > -1){
		args = args.slice(1);
	}
	if (args[0] === '-i'){
		interactive = true;
		args = args.slice(1);
	}
	if (!args.length) interactive = true;	

	args.forEach(function(file){
		parse('(begin '
			+fs.readFileSync(process.env.PWD+'/'+file, 'utf-8')
				+')', global);
	});
} else {
	interactive = false;
}

if (interactive) {
	var repl = rl.createInterface(
		process.stdin, 
		process.stdout, null);

	var prompt = 'jils> ',
		colors = {
			pre: "\033[1;31m", 
			post: "\033[m"
		};

	var issue = fs.readFileSync('./issue.txt');
	console.log(issue.toString());	
	
	repl.question(prompt, function next(input){
		if (!input) return repl.question(prompt, next);
		switch (input.split(' ')[0]){
			case ':q': process.exit(0);
		} 
		var result = parse(input, global),
			output = colors.pre + result + colors.post;
		console.log(output);
		repl.question(prompt, next);
	});
}
